@@ -1,21 +1,18 @@
 # This file is part of python-markups module
-# License: BSD
-# Copyright: (C) Dmitry Shachnev, 2012
+# License: 3-clause BSD, see LICENSE file
+# Copyright: (C) Dmitry Shachnev, 2012-2018
 
 import os.path
 
 # Some common constants and functions
 (LANGUAGE_HOME_PAGE, MODULE_HOME_PAGE, SYNTAX_DOCUMENTATION) = range(3)
-CONFIGURATION_DIR = (os.environ.get('XDG_CONFIG_HOME') or
+CONFIGURATION_DIR = (os.getenv('XDG_CONFIG_HOME') or os.getenv('APPDATA') or
 	os.path.expanduser('~/.config'))
 MATHJAX_LOCAL_URL = 'file:///usr/share/javascript/mathjax/MathJax.js'
-MATHJAX_WEB_URL = 'https://cdn.mathjax.org/mathjax/latest/MathJax.js'
+MATHJAX_WEB_URL = 'https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.4/MathJax.js'
 
 PYGMENTS_STYLE = 'default'
 
-class MarkupsWarning(RuntimeWarning):
-	pass
-
 def get_pygments_stylesheet(selector, style=None):
 	if style is None:
 		style = PYGMENTS_STYLE
