@@ -1,10 +1,12 @@
 # vim: ts=8:sts=8:sw=8:noexpandtab
 
 # This file is part of python-markups test suite
-# License: BSD
-# Copyright: (C) Dmitry Shachnev, 2012-2016
+# License: 3-clause BSD, see LICENSE file
+# Copyright: (C) Dmitry Shachnev, 2012-2018
 
 from markups.markdown import MarkdownMarkup, _canonicalized_ext_names
+from os import remove
+from tempfile import NamedTemporaryFile
 import unittest
 import warnings
 
@@ -74,7 +76,7 @@ $$m_1$$ text $$m_2$$
 
 mathjax_output = \
 r'''<p>
-<script type="math/tex">i_1</script> some text \$escaped\$ <script type="math/tex">i_2</script>
+<script type="math/tex">i_1</script> some text $escaped$ <script type="math/tex">i_2</script>
 </p>
 <p>
 <script type="math/tex">\LaTeX</script> \(escaped)</p>
@@ -90,7 +92,7 @@ r'''<p>
 <p>
 <script type="math/tex; mode=display"> \alpha </script> text <script type="math/tex; mode=display"> \beta </script>
 </p>
-<p>\$$escaped\$$ \[escaped]</p>
+<p>$$escaped$$ \[escaped]</p>
 '''
 
 mathjax_multiline_source = \
@@ -148,8 +150,9 @@ class MarkdownTest(unittest.TestCase):
 		self.assertIsNone(markup._canonicalize_extension_name('nonexistent(someoption)'))
 		self.assertIsNone(markup._canonicalize_extension_name('.foobar'))
 		self.assertEqual(markup._canonicalize_extension_name('meta'), 'markdown.extensions.meta')
-		self.assertEqual(markup._canonicalize_extension_name('meta(someoption)'),
-			'markdown.extensions.meta(someoption)')
+		name, parameters = markup._split_extension_config('toc(anchorlink=1, foo=bar)')
+		self.assertEqual(name, 'toc')
+		self.assertEqual(parameters, {'anchorlink': '1', 'foo': 'bar'})
 
 	def test_loading_extensions_by_module_name(self):
 		markup = MarkdownMarkup(extensions=['markdown.extensions.footnotes'])
@@ -169,8 +172,7 @@ class MarkdownTest(unittest.TestCase):
 		html = markup.convert('## Header').get_document_body()
 		self.assertEqual(html,
 			'<h2 id="header"><a class="toclink" href="#header">Header</a></h2>\n')
-		self.assertEqual(_canonicalized_ext_names['toc(anchorlink=1)'],
-			'markdown.extensions.toc(anchorlink=1)')
+		self.assertEqual(_canonicalized_ext_names['toc'], 'markdown.extensions.toc')
 
 	def test_document_extensions_parameters(self):
 		markup = MarkdownMarkup(extensions=[])
@@ -251,11 +253,24 @@ class MarkdownTest(unittest.TestCase):
 		body = markup.convert(mathjax_multilevel_source).get_document_body()
 		self.assertEqual(mathjax_multilevel_output, body)
 
+	def test_mathjax_asciimath(self):
+		markup = MarkdownMarkup(extensions=['mdx_math(use_asciimath=1)'])
+		converted = markup.convert('\( [[a,b],[c,d]] \)')
+		body = converted.get_document_body()
+		self.assertIn('<script type="math/asciimath">', body)
+		self.assertIn('<script type="text/javascript"', converted.get_javascript())
+
 	@unittest.skipUnless(hasattr(unittest.TestCase, 'assertWarnsRegex'), 'assertWarnsRegex is not supported')
 	def test_not_loading_sys(self):
 		with self.assertWarnsRegex(ImportWarning, 'Extension "sys" does not exist.'):
 			markup = MarkdownMarkup(extensions=['sys'])
 		self.assertNotIn('sys', markup.extensions)
 
-if __name__ == '__main__':
-	unittest.main()
+	def test_extensions_file(self):
+		f = NamedTemporaryFile(mode="w", delete=False)
+		f.write("foo\n# bar\nbaz\n")
+		f.close()
+		markup = MarkdownMarkup()
+		extensions = markup._load_extensions_list_from_file(f.name)
+		self.assertEqual(extensions, ["foo", "baz"])
+		remove(f.name)
