@@ -1,8 +1,8 @@
 # vim: ts=8:sts=8:sw=8:noexpandtab
 
 # This file is part of python-markups test suite
-# License: BSD
-# Copyright: (C) Dmitry Shachnev, 2012-2017
+# License: 3-clause BSD, see LICENSE file
+# Copyright: (C) Dmitry Shachnev, 2012-2018
 
 import unittest
 from markups import ReStructuredTextMarkup
@@ -26,7 +26,7 @@ class ReStructuredTextTest(unittest.TestCase):
 		stylesheet = converted.get_stylesheet()
 		text_expected = ('<div class="document" id="hello-world">\n'
 			'<h1 class="title">Hello, world!</h1>\n'
-			'<h2 class="subtitle" id="some-subtitle">Some subtitle</h2>\n'
+			'<p class="subtitle" id="some-subtitle">Some subtitle</p>\n'
 			'<p>This is an example <strong>reStructuredText</strong> document.</p>\n'
 			'</div>\n')
 		title_expected = 'Hello, world!'
@@ -56,5 +56,11 @@ class ReStructuredTextTest(unittest.TestCase):
 		body = markup.convert('`').get_document_body() # unclosed role
 		self.assertNotIn('system-message', body)
 
-if __name__ == '__main__':
-	unittest.main()
+	def test_whole_html(self):
+		markup = ReStructuredTextMarkup()
+		text = basic_text + "\n\n.. math::\n   \sin \varphi"
+		html = markup.convert(text).get_whole_html()
+		self.assertIn("<title>Hello, world!</title>", html)
+		self.assertIn('<style type="text/css">', html)
+		self.assertIn('<script type="text/javascript"', html)
+		self.assertIn('This is an example', html)
